<?php
use Icinga\Data\Filter\Filter;
use Icinga\Module\Monitoring\Object\Service;
use Icinga\Web\Url;

if (! $this->compact): ?>
<div class="controls">
    <?= $this->tabs ?>
    <?= $this->problemToggle ?>
    <div class="sort-controls-container">
        <?= $this->sortBox ?>
    </div>
    <?= $this->filterEditor ?>
</div>
<?php endif ?>
<div class="content" data-base-target="_next">
    <?php if (empty($pivotData)): ?>
    <p><?= $this->translate('No services found matching the filter.') ?></p>
</div>
<?php return; endif;
$serviceFilter = Filter::matchAny();
foreach ($pivotData as $serviceDescription => $_) {
    $serviceFilter->orFilter(Filter::where('service_description', $serviceDescription));
}
?>
<table class="service-grid-table">
    <thead>
        <tr>
            <th><?= $this->partial(
                'joystickPagination.phtml',
                'default',
                array(
                    'flippable'      => true,
                    'xAxisPaginator' => $horizontalPaginator,
                    'yAxisPaginator' => $verticalPaginator
                )
            ) ?></th>
            <?php foreach ($pivotHeader['cols'] as $hostName => $hostAlias): ?>
            <th class="rotate-45"><div><span><?= $this->qlink(
                $this->ellipsis($hostAlias, 24),
                Url::fromPath('monitoring/list/services')->addFilter(
                    Filter::matchAll($serviceFilter, Filter::where('host_name', $hostName))
                ),
                null,
                array('title' => sprintf($this->translate('List all reported services on host %s'), $hostAlias)),
                false
            ) ?></span></div></th>
            <?php endforeach ?>
        </tr>
    </thead>
    <tbody>

    <?php $i = 0 ?>
    <?php foreach ($pivotHeader['rows'] as $serviceDescription => $serviceDisplayName): ?>
        <tr>
            <th><?php
                $hostFilter = Filter::matchAny();
                foreach ($pivotData[$serviceDescription] as $hostName => $_) {
                    $hostFilter->orFilter(Filter::where('host_name', $hostName));
                }
                echo $this->qlink(
                    $serviceDisplayName,
                    Url::fromPath('monitoring/list/services')->addFilter(
                        Filter::matchAll($hostFilter, Filter::where('service_description', $serviceDescription))
                    ),
                    null,
                    array('title' => sprintf(
                        $this->translate('List all services with the name "%s" on all reported hosts'),
                        $serviceDisplayName
                    ))
                );
            ?></th>
        <?php foreach (array_keys($pivotHeader['cols']) as $hostName): ?>
            <td><?php
            $service = $pivotData[$serviceDescription][$hostName];
            if ($service === null): ?>
                <span aria-hidden="true">&middot;</span>
                <?php continue; endif ?>
            <?php $ariaDescribedById = $this->protectId($service->host_name . '_' . $service->service_description . '_desc') ?>
                <span class="sr-only" id="<?= $ariaDescribedById ?>">
                    <?= $this->escape($service->service_output) ?>
                </span>
                <?= $this->qlink(
                    '',
                    'monitoring/service/show',
                    array(
                        'host'    => $hostName,
                        'service' => $serviceDescription
                    ),
                    array(
                        'aria-describedby'    => $ariaDescribedById,
                        'aria-label'          => sprintf(
                            $this->translate('Show detailed information for service %s on host %s'),
                            $service->service_display_name,
                            $service->host_display_name
                        ),
                        'class'               => 'service-grid-link state-' . Service::getStateText($service->service_state) . ($service->service_handled ? ' handled' : ''),
                        'title'               => $service->service_output
                    )
                ) ?>
            </td>
        <?php endforeach ?>
        <?php if (! $this->compact && $this->horizontalPaginator->getPages()->pageCount > 1): ?>
            <td>
                <?php $expandLink = $this->qlink(
                    $this->translate('Load more'),
                    Url::fromRequest(),
                    array(
                        'limit' => ($this->horizontalPaginator->getItemCountPerPage() + 20)
                            . ','
                            .  $this->verticalPaginator->getItemCountPerPage()
                    ),
                    array(
                        'class'             => 'action-link',
                        'data-base-target'  => '_self'
                    )
                ) ?>
                <?= ++$i === (int) ceil(count($pivotHeader['rows']) / 2) ? $expandLink : '' ?>
            </td>
        <?php endif ?>
        </tr>
    <?php endforeach ?>
    <?php if (! $this->compact && $this->verticalPaginator->getPages()->pageCount > 1): ?>
        <tr>
            <td colspan="<?= count($pivotHeader['cols']) + 1?>" class="service-grid-table-more">
                <?php echo $this->qlink(
                    $this->translate('Load more'),
                    Url::fromRequest(),
                    array(
                        'limit' => $this->horizontalPaginator->getItemCountPerPage()
                            . ','
                            . ($this->verticalPaginator->getItemCountPerPage() + 20)
                    ),
                    array(
                        'class'             => 'action-link',
                        'data-base-target'  => '_self'
                    )
                ) ?>
            </td>
        </tr>
    <?php endif ?>
    </tbody>
</table>
</div>
