<?php use Icinga\Data\Filter\Filter; ?>
<div class="controls controls-separated">
<?php if (! $this->compact): ?>
    <?= $this->tabs ?>
<?php endif ?>
    <?= $this->render('partials/object/host-header.phtml') ?>
<?php
    $this->stats = $object->stats;
    $this->baseFilter = Filter::where('host', $object->host_name);
    echo $this->render('list/components/servicesummary.phtml');
?>
    <?= $this->render('partials/object/quick-actions.phtml') ?>
</div>
<?= $this->render('partials/object/detail-content.phtml') ?>
