<div class="controls">
<?php if (! $this->compact): ?>
    <?= $this->tabs ?>
<?php endif ?>
    <?= $this->render('partials/downtime/downtimes-header.phtml') ?>
</div>

<div class="content multi-commands">
    <h2> <?= $this->translate('Commands') ?> </h2>
    <?= $this->qlink(
        sprintf($this->translate('Remove all %d scheduled downtimes'), $downtimes->count()),
        $removeAllLink,
        null,
        array(
            'icon'  => 'trash',
            'title' => $this->translate('Remove all selected downtimes')
        )
    ) ?>
</div>
