<div class="controls">
<?php if (! $this->compact): ?>
    <?= $tabs ?>
<?php endif ?>
<?php if (isset($serviceStates)): ?>
    <?= $this->render('list/components/servicesummary.phtml') ?>
    <?= $this->render('partials/service/objects-header.phtml') ?>
<?php else: ?>
    <?= $this->render('list/components/hostssummary.phtml') ?>
    <?= $this->render('partials/host/objects-header.phtml') ?>
<?php endif ?>
</div>
<div class="content objects-command">
    <?= $form ?>
</div>
