<div class="controls">
    
  <?php if (! $this->compact): ?>
    <?= $this->tabs; ?>
  <?php endif ?>

  <?= $this->render('partials/downtime/downtimes-header.phtml'); ?>
</div>

<div class="content object-command">
    <?= $delAllDowntimeForm ?>
</div>