<?php if (! $this->compact): ?>
<div class="controls">
    <?= $this->tabs ?>
    <?= $this->paginator ?>
    <div class="sort-controls-container">
        <?= $this->limiter ?>
        <?= $this->sortBox ?>
    </div>
    <?= $this->filterEditor ?>
</div>
<?php endif ?>
<div class="content">
<?php if (! $contacts->hasResult()): ?>
    <p><?= $this->translate('No contacts found matching the filter') ?></p>
</div>
<?php return; endif ?>
    <table class="common-table table-row-selectable" data-base-target="_next">
    <thead>
        <tr>
            <th><?= $this->translate('Name') ?></th>
            <th><?= $this->translate('Email') ?></th>
            <th><?= $this->translate('Pager') ?></th>
        </tr>
    </thead>
    <tbody>
    <?php foreach ($contacts->peekAhead($this->compact) as $contact): ?>
        <tr>
        <th>
            <?= $this->qlink(
                $contact->contact_name,
                'monitoring/show/contact',
                array('contact_name' => $contact->contact_name),
                array(
                    'title' => sprintf(
                        $this->translate('Show detailed information about %s'),
                        $contact->contact_alias
                    )
                )
            ) ?>
        </th>
        <td>
            <?= $this->translate('Email') ?>:
            <a href="mailto:<?= $contact->contact_email ?>"
               title="<?= sprintf($this->translate('Send a mail to %s'), $contact->contact_alias) ?>"
               aria-label="<?= sprintf($this->translate('Send a mail to %s'), $contact->contact_alias) ?>">
                <?= $this->escape($contact->contact_email) ?>
            </a>
        </td>
            <td>
            <?php if ($contact->contact_pager): ?>
                <?= $this->escape($contact->contact_pager) ?>
            <?php endif ?>
            </td>

            <?php if ($contact->contact_notify_service_timeperiod): ?>
            <td>
                <?= $this->escape($contact->contact_notify_service_timeperiod) ?>
            </td>
            <?php endif ?>

            <?php if ($contact->contact_notify_host_timeperiod): ?>
            <td>
                <?= $this->escape($contact->contact_notify_host_timeperiod) ?>
            </td>
            <?php endif ?>
        </tr>
    <?php endforeach ?>
    </tbody>
    </table>
<?php if ($contacts->hasMore()): ?>
    <div class="dont-print action-links">
        <?= $this->qlink(
            $this->translate('Show More'),
            $this->url()->without(array('showCompact', 'limit')),
            null,
            array(
                'class'             => 'action-link',
                'data-base-target'  => '_next'
            )
        ) ?>
    </div>
<?php endif ?>
</div>
