<?php
$parts = explode('!', $object->check_command);
$command = array_shift($parts);

if ($showInstance): ?>
<tr>
    <th><?= $this->translate('Instance') ?></th>
    <td><?= $this->escape($object->instance_name) ?></td>
</tr>
<?php endif ?>
<tr>
    <th><?= $this->translate('Command') ?></th>
    <td>
        <?= $this->escape($command) ?>
        <?php if ($this->hasPermission('monitoring/command/process-check-result') && $object->passive_checks_enabled) {
            $title = sprintf(
                $this->translate('Submit a one time or so called passive result for the %s check'), $command
            );
            if ($object->getType() === $object::TYPE_HOST) {
                echo $this->qlink(
                    $this->translate('Process check result'),
                    'monitoring/host/process-check-result',
                    array('host' => $object->getName()),
                    array(
                        'class'             => 'action-link',
                        'data-base-target'  => '_self',
                        'icon'              => 'edit',
                        'title'             => $title
                    )
                );
            } else {
                echo $this->qlink(
                    $this->translate('Process check result'),
                    'monitoring/service/process-check-result',
                    array('host' => $object->getHost()->getName(), 'service' => $object->getName()),
                    array(
                        'class'             => 'action-link',
                        'data-base-target'  => '_self',
                        'icon'              => 'edit',
                        'title'             => $title
                    )
                );
            }
        } ?>
    </td>
</tr>

<?php
$row = "<tr>\n  <th>%s</th>\n  <td>%s</td>\n</tr>\n";
for ($i = 0; $i < count($parts); $i++) {
    printf($row, '$ARG' . ($i + 1) . '$', $this->escape($parts[$i]));
}
